@@ -53,9 +53,19 @@ typedef std::map<std::string, uint8_t> Extensions;
 
 #define DEFAULT_MAX_OUTSTANDING_REQUEST 6
 
+#define OUTSTANDING_REQUEST_STEP 6
+
 // Upper Bound of the number of outstanding request
-#define UB_MAX_OUTSTANDING_REQUEST 24
+#define UB_MAX_OUTSTANDING_REQUEST 100
 
 #define METADATA_PIECE_SIZE (16*1024)
 
+#define LPD_MULTICAST_ADDR "239.192.152.143"
+
+#define LPD_MULTICAST_PORT 6771
+
+#define COMPACT_LEN_IPV4 6
+
+#define COMPACT_LEN_IPV6 18
+
 #endif // _D_BT_CONSTANTS_
