@@ -39,11 +39,11 @@
 
 #include <string>
 #include <deque>
+#include <vector>
 #include <algorithm>
 
 #include "a2time.h"
 #include "Cookie.h"
-#include "CookieParser.h"
 
 namespace aria2 {
 
@@ -56,17 +56,20 @@ public:
 
   class DomainEntry {
   private:
-    std::string _key;
+    // This is reversed domain level string.
+    // e.g. net.sourceforge.aria2
+    // e.g. 192.168.0.1
+    std::string key_;
 
-    time_t _lastAccess;
+    time_t lastAccessTime_;
 
-    std::deque<Cookie> _cookies;
+    std::deque<Cookie> cookies_;
   public:
     DomainEntry(const std::string& domain);
 
     const std::string& getKey() const
     {
-      return _key;
+      return key_;
     }
 
     template<typename OutputIterator>
@@ -74,12 +77,12 @@ public:
     (OutputIterator out,
      const std::string& requestHost,
      const std::string& requestPath,
-     time_t date, bool secure)
+     time_t now, bool secure)
     {
-      for(std::deque<Cookie>::iterator i = _cookies.begin();
-          i != _cookies.end(); ++i) {
-        if((*i).match(requestHost, requestPath, date, secure)) {
-          (*i).updateLastAccess();
+      for(std::deque<Cookie>::iterator i = cookies_.begin(),
+            eoi = cookies_.end(); i != eoi; ++i) {
+        if((*i).match(requestHost, requestPath, now, secure)) {
+          (*i).setLastAccessTime(now);
           out++ = *i;
         }
       }
@@ -88,16 +91,19 @@ public:
 
     size_t countCookie() const
     {
-      return _cookies.size();
+      return cookies_.size();
     }
 
-    bool addCookie(const Cookie& cookie);
+    bool addCookie(const Cookie& cookie, time_t now);
 
-    void updateLastAccess();
-
-    time_t getLastAccess() const
+    void setLastAccessTime(time_t lastAccessTime)
     {
-      return _lastAccess;
+      lastAccessTime_ = lastAccessTime;
+    }
+
+    time_t getLastAccessTime() const
+    {
+      return lastAccessTime_;
     }
 
     void writeCookie(std::ostream& o) const;
@@ -107,49 +113,58 @@ public:
     template<typename OutputIterator>
     OutputIterator dumpCookie(OutputIterator out) const
     {
-      return std::copy(_cookies.begin(), _cookies.end(), out);
+      return std::copy(cookies_.begin(), cookies_.end(), out);
     }
 
     bool operator<(const DomainEntry& de) const
     {
-      return _key < de._key;
+      return key_ < de.key_;
     }
   };
 private:
-  std::deque<DomainEntry> _domains;
+  std::deque<DomainEntry> domains_;
 
-  CookieParser _parser;
+  Logger* logger_;
 
-  Logger* _logger;
-
-  void storeCookies(const std::deque<Cookie>& cookies);
+  template<typename InputIterator>
+  void storeCookies(InputIterator first, InputIterator last, time_t now)
+  {
+    for(; first != last; ++first) {
+      store(*first, now);
+    }
+  }
 public:
   CookieStorage();
 
   ~CookieStorage();
 
   // Returns true if cookie is stored or updated existing cookie.
-  // Returns false if cookie is expired.
-  bool store(const Cookie& cookie);
+  // Returns false if cookie is expired. now is used as last access
+  // time.
+  bool store(const Cookie& cookie, time_t now);
 
   // Returns true if cookie is stored or updated existing cookie.
-  // Otherwise, returns false.
-  bool parseAndStore(const std::string& setCookieString,
-                     const std::string& requestHost,
-                     const std::string& requestPath);
+  // Otherwise, returns false. now is used as creation time and last
+  // access time.
+  bool parseAndStore
+  (const std::string& setCookieString,
+   const std::string& requestHost,
+   const std::string& requestPath,
+   time_t now);
 
   // Finds cookies matched with given criteria and returns them.
-  // Matched cookies' _lastAccess property is updated.
-  std::deque<Cookie> criteriaFind(const std::string& requestHost,
-                                  const std::string& requestPath,
-                                  time_t date, bool secure);
+  // Matched cookies' lastAccess_ property is updated.
+  std::vector<Cookie> criteriaFind(const std::string& requestHost,
+                                   const std::string& requestPath,
+                                   time_t now, bool secure);
 
   // Loads Cookies from file denoted by filename.  If compiled with
   // libsqlite3, this method automatically detects the specified file
   // is sqlite3 or just plain text file and calls appropriate parser
   // implementation class.  If Cookies are successfully loaded, this
-  // method returns true.  Otherwise, this method returns false.
-  bool load(const std::string& filename);
+  // method returns true.  Otherwise, this method returns false.  now
+  // is used as creation time and last access time.
+  bool load(const std::string& filename, time_t now);
   
   // Saves Cookies in Netspace format which is used in
   // Firefox1.2/Netscape/Mozilla.  If Cookies are successfully saved,
@@ -166,8 +181,8 @@ public:
   template<typename OutputIterator>
   OutputIterator dumpCookie(OutputIterator out) const
   {
-    for(std::deque<DomainEntry>::const_iterator i = _domains.begin();
-        i != _domains.end(); ++i) {
+    for(std::deque<DomainEntry>::const_iterator i = domains_.begin(),
+          eoi = domains_.end(); i != eoi; ++i) {
       out = (*i).dumpCookie(out);
     }
     return out;
