@@ -42,26 +42,29 @@
 
 #include "SharedHandle.h"
 #include "a2time.h"
+#include "ValueBase.h"
 
 namespace aria2 {
 
 class DHTMessage;
+class DHTResponseMessage;
 class DHTMessageCallback;
 class DHTRoutingTable;
 class DHTMessageFactory;
 class DHTMessageTrackerEntry;
 class Logger;
-class BDE;
 
 class DHTMessageTracker {
 private:
-  std::deque<SharedHandle<DHTMessageTrackerEntry> > _entries;
+  std::deque<SharedHandle<DHTMessageTrackerEntry> > entries_;
   
-  SharedHandle<DHTRoutingTable> _routingTable;
+  SharedHandle<DHTRoutingTable> routingTable_;
 
-  SharedHandle<DHTMessageFactory> _factory;
+  SharedHandle<DHTMessageFactory> factory_;
 
-  Logger* _logger;
+  Logger* logger_;
+
+  void handleTimeoutEntry(const SharedHandle<DHTMessageTrackerEntry>& entry);
 public:
   DHTMessageTracker();
 
@@ -72,13 +75,14 @@ public:
                   const SharedHandle<DHTMessageCallback>& callback =
                   SharedHandle<DHTMessageCallback>());
 
-  std::pair<SharedHandle<DHTMessage>, SharedHandle<DHTMessageCallback> >
-  messageArrived(const BDE& dict,
+  std::pair<SharedHandle<DHTResponseMessage>, SharedHandle<DHTMessageCallback> >
+  messageArrived(const Dict* dict,
                  const std::string& ipaddr, uint16_t port);
 
   void handleTimeout();
 
-  SharedHandle<DHTMessageTrackerEntry> getEntryFor(const SharedHandle<DHTMessage>& message) const;
+  SharedHandle<DHTMessageTrackerEntry> getEntryFor
+  (const SharedHandle<DHTMessage>& message) const;
 
   size_t countEntry() const;
 
