@@ -37,6 +37,8 @@
 
 #include "PieceStorage.h"
 
+#include <deque>
+
 namespace aria2 {
 
 class DownloadContext;
@@ -52,49 +54,47 @@ class PieceSelector;
 
 class HaveEntry {
 private:
-  int32_t cuid;
-  size_t index;
-  Time registeredTime;
+  cuid_t cuid_;
+  size_t index_;
+  Timer registeredTime_;
 public:
-  HaveEntry(int32_t cuid, size_t index):
-    cuid(cuid),
-    index(index) {}
+  HaveEntry(cuid_t cuid, size_t index, const Timer& registeredTime):
+    cuid_(cuid),
+    index_(index),
+    registeredTime_(registeredTime) {}
 
-  int32_t getCuid() const { return cuid; }
+  cuid_t getCuid() const { return cuid_; }
 
-  size_t getIndex() const { return index; }
+  size_t getIndex() const { return index_; }
 
-  const Time& getRegisteredTime() const { return registeredTime; }
+  const Timer& getRegisteredTime() const { return registeredTime_; }
 };
 
-typedef std::deque<HaveEntry> Haves;
-
 class DefaultPieceStorage : public PieceStorage {
 private:
-  SharedHandle<DownloadContext> downloadContext;
-  BitfieldMan* bitfieldMan;
-  SharedHandle<DiskAdaptor> diskAdaptor;
-  SharedHandle<DiskWriterFactory> _diskWriterFactory;
-  std::deque<SharedHandle<Piece> > usedPieces;
+  SharedHandle<DownloadContext> downloadContext_;
+  BitfieldMan* bitfieldMan_;
+  SharedHandle<DiskAdaptor> diskAdaptor_;
+  SharedHandle<DiskWriterFactory> diskWriterFactory_;
+  std::deque<SharedHandle<Piece> > usedPieces_;
 
-  size_t endGamePieceNum;
-  Logger* logger;
-  const Option* option;
-  Haves haves;
+  bool endGame_;
+  size_t endGamePieceNum_;
+  Logger* logger_;
+  const Option* option_;
+  std::deque<HaveEntry> haves_;
 
-  SharedHandle<PieceStatMan> _pieceStatMan;
+  SharedHandle<PieceStatMan> pieceStatMan_;
 
-  SharedHandle<PieceSelector> _pieceSelector;
-
-  bool getMissingPieceIndex(size_t& index,
-                            const unsigned char* bitfield, size_t length);
-
-  SharedHandle<Piece> getMissingPiece(const unsigned char* bitfield,
-                                      size_t length);
-
-  SharedHandle<Piece> getMissingPiece(const BitfieldMan& bitfield);
+  SharedHandle<PieceSelector> pieceSelector_;
 
 #ifdef ENABLE_BITTORRENT
+  void getMissingPiece
+  (std::vector<SharedHandle<Piece> >& pieces,
+   size_t minMissingBlocks,
+   const unsigned char* bitfield,
+   size_t length);
+
   void createFastIndexBitfield(BitfieldMan& bitfield,
                                const SharedHandle<Peer>& peer);
 #endif // ENABLE_BITTORRENT
@@ -121,22 +121,45 @@ public:
 
   virtual bool hasMissingPiece(const SharedHandle<Peer>& peer);
 
+  virtual void getMissingPiece
+  (std::vector<SharedHandle<Piece> >& pieces,
+   size_t minMissingBlocks,
+   const SharedHandle<Peer>& peer);
+
+  virtual void getMissingPiece
+  (std::vector<SharedHandle<Piece> >& pieces,
+   size_t minMissingBlocks,
+   const SharedHandle<Peer>& peer,
+   const std::vector<size_t>& excludedIndexes);
+
+  virtual void getMissingFastPiece
+  (std::vector<SharedHandle<Piece> >& pieces,
+   size_t minMissingBlocks,
+   const SharedHandle<Peer>& peer);
+
+  virtual void getMissingFastPiece
+  (std::vector<SharedHandle<Piece> >& pieces,
+   size_t minMissingBlocks,
+   const SharedHandle<Peer>& peer,
+   const std::vector<size_t>& excludedIndexes);
+
   virtual SharedHandle<Piece> getMissingPiece(const SharedHandle<Peer>& peer);
 
-  virtual SharedHandle<Piece> getMissingFastPiece(const SharedHandle<Peer>& peer);
+  virtual  SharedHandle<Piece> getMissingPiece
+  (const SharedHandle<Peer>& peer, const std::vector<size_t>& excludedIndexes);
 
-  virtual SharedHandle<Piece> getMissingPiece
-  (const SharedHandle<Peer>& peer, const std::deque<size_t>& excludedIndexes);
+  SharedHandle<Piece> getMissingFastPiece
+  (const SharedHandle<Peer>& peer);
 
-  virtual SharedHandle<Piece> getMissingFastPiece
-  (const SharedHandle<Peer>& peer, const std::deque<size_t>& excludedIndexes);
+  SharedHandle<Piece> getMissingFastPiece
+  (const SharedHandle<Peer>& peer, const std::vector<size_t>& excludedIndexes);
 
 #endif // ENABLE_BITTORRENT
 
   virtual bool hasMissingUnusedPiece();
 
   virtual SharedHandle<Piece> getSparseMissingUnusedPiece
-  (const unsigned char* ignoreBitfield, size_t length);
+  (size_t minSplitSize, const unsigned char* ignoreBitfield, size_t length);
 
   virtual SharedHandle<Piece> getMissingPiece(size_t index);
 
@@ -176,26 +199,34 @@ public:
   virtual const unsigned char* getBitfield();
 
   virtual void setEndGamePieceNum(size_t num) {
-    endGamePieceNum = num;
+    endGamePieceNum_ = num;
   }
 
   size_t getEndGamePieceNum() const {
-    return endGamePieceNum;
+    return endGamePieceNum_;
   }
 
   virtual bool isSelectiveDownloadingMode();
 
-  virtual bool isEndGame();
+  virtual bool isEndGame()
+  {
+    return endGame_;
+  }
   
+  virtual void enterEndGame()
+  {
+    endGame_ = true;
+  }
+
   virtual SharedHandle<DiskAdaptor> getDiskAdaptor();
 
   virtual size_t getPieceLength(size_t index);
 
-  virtual void advertisePiece(int32_t cuid, size_t index);
+  virtual void advertisePiece(cuid_t cuid, size_t index);
 
   virtual void
-  getAdvertisedPieceIndexes(std::deque<size_t>& indexes,
-                            int32_t myCuid, const Time& lastCheckTime);
+  getAdvertisedPieceIndexes(std::vector<size_t>& indexes,
+                            cuid_t myCuid, const Timer& lastCheckTime);
 
   virtual void removeAdvertisedPiece(time_t elapsed);
 
@@ -205,11 +236,13 @@ public:
 
   virtual void markPieceMissing(size_t index);
 
-  virtual void addInFlightPiece(const std::deque<SharedHandle<Piece> >& pieces);
+  virtual void addInFlightPiece
+  (const std::vector<SharedHandle<Piece> >& pieces);
 
   virtual size_t countInFlightPiece();
 
-  virtual void getInFlightPieces(std::deque<SharedHandle<Piece> >& pieces);
+  virtual void getInFlightPieces
+  (std::vector<SharedHandle<Piece> >& pieces);
 
   virtual void addPieceStats(size_t index);
 
@@ -223,28 +256,30 @@ public:
                                 size_t newBitfieldLength,
                                 const unsigned char* oldBitfield);
 
+  virtual size_t getNextUsedIndex(size_t index);
+
   /**
    * This method is made private for test purpose only.
    */
   void addUsedPiece(const SharedHandle<Piece>& piece);
 
-  void setDiskWriterFactory(const SharedHandle<DiskWriterFactory>& diskWriterFactory);
+  void setDiskWriterFactory
+  (const SharedHandle<DiskWriterFactory>& diskWriterFactory);
 
   const SharedHandle<PieceStatMan>& getPieceStatMan() const
   {
-    return _pieceStatMan;
+    return pieceStatMan_;
   }
 
   void setPieceSelector(const SharedHandle<PieceSelector>& pieceSelector)
   {
-    _pieceSelector = pieceSelector;
+    pieceSelector_ = pieceSelector;
   }
 
-  SharedHandle<PieceSelector> getPieceSelector() const
+  const SharedHandle<PieceSelector>& getPieceSelector() const
   {
-    return _pieceSelector;
+    return pieceSelector_;
   }
-    
 };
 
 typedef SharedHandle<DefaultPieceStorage> DefaultPieceStorageHandle;
