@@ -48,6 +48,11 @@
 #include "RequestGroup.h"
 #include "Logger.h"
 #include "DownloadContext.h"
+#include "RequestGroupMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
+#include "ServerStatMan.h"
+#include "util.h"
 
 namespace aria2 {
 
@@ -60,35 +65,49 @@ FtpFinishDownloadCommand::FtpFinishDownloadCommand
  DownloadEngine* e,
  const SharedHandle<SocketCore>& socket)
   :AbstractCommand(cuid, req, fileEntry, requestGroup, e, socket),
-   _ftpConnection(ftpConnection)
+   ftpConnection_(ftpConnection)
 {}
 
 // overrides AbstractCommand::execute().
 // AbstractCommand::_segments is empty.
 bool FtpFinishDownloadCommand::execute()
 {
-  if(_requestGroup->isHaltRequested()) {
+  if(getRequestGroup()->isHaltRequested()) {
     return true;
   }
   try {
-    unsigned int status = _ftpConnection->receiveResponse();
-    if(status == 0) {
-      e->commands.push_back(this);
+    if(readEventEnabled() || hupEventEnabled()) {
+      getCheckPoint().reset();
+      unsigned int status = ftpConnection_->receiveResponse();
+      if(status == 0) {
+        getDownloadEngine()->addCommand(this);
+        return false;
+      }
+      if(status == 226) {
+        if(getOption()->getAsBool(PREF_FTP_REUSE_CONNECTION)) {
+          std::map<std::string, std::string> options;
+          options["baseWorkingDir"] = ftpConnection_->getBaseWorkingDir();
+          getDownloadEngine()->poolSocket
+            (getRequest(), ftpConnection_->getUser(), createProxyRequest(),
+             getSocket(), options);
+        }
+      } else {
+        getLogger()->info("CUID#%s - Bad status for transfer complete.",
+                          util::itos(getCuid()).c_str());
+      }
+    } else if(getCheckPoint().difference(global::wallclock) >= getTimeout()) {
+      getLogger()->info("CUID#%s - Timeout before receiving transfer complete.",
+                        util::itos(getCuid()).c_str());
+    } else {
+      getDownloadEngine()->addCommand(this);
       return false;
     }
-    if(status != 226) {
-      throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
-    }
-    if(getOption()->getAsBool(PREF_FTP_REUSE_CONNECTION)) {
-      std::map<std::string, std::string> options;
-      options["baseWorkingDir"] = _ftpConnection->getBaseWorkingDir();
-      e->poolSocket(req, _ftpConnection->getUser(), createProxyRequest(),
-                    socket, options);
-    }
   } catch(RecoverableException& e) {
-    logger->info(EX_EXCEPTION_CAUGHT, e);
+    getLogger()->info("CUID#%s - Exception was thrown, but download was"
+                      " finished, so we can ignore the exception.",
+                      e, util::itos(getCuid()).c_str());
   }
-  if(_requestGroup->downloadFinished()) {
+  if(getRequestGroup()->downloadFinished()) {
     return true;
   } else {
     return prepareForRetry(0);
