@@ -78,8 +78,20 @@ const std::string HttpHeader::HTTP_1_1("HTTP/1.1");
 
 const std::string HttpHeader::S200("200");
 
+const std::string HttpHeader::S206("206");
+
 const std::string HttpHeader::S300("300");
 
+const std::string HttpHeader::S301("301");
+
+const std::string HttpHeader::S302("302");
+
+const std::string HttpHeader::S303("303");
+
+const std::string HttpHeader::S304("304");
+
+const std::string HttpHeader::S307("307");
+
 const std::string HttpHeader::S400("400");
 
 const std::string HttpHeader::S401("401");
@@ -87,18 +99,19 @@ const std::string HttpHeader::S401("401");
 const std::string HttpHeader::S404("404");
 
 void HttpHeader::put(const std::string& name, const std::string& value) {
-  std::multimap<std::string, std::string>::value_type vt(util::toLower(name), value);
-  table.insert(vt);
+  std::multimap<std::string, std::string>::value_type vt
+    (util::toLower(name), value);
+  table_.insert(vt);
 }
 
 bool HttpHeader::defined(const std::string& name) const {
-  return table.count(util::toLower(name)) >= 1;
+  return table_.count(util::toLower(name)) >= 1;
 }
 
 const std::string& HttpHeader::getFirst(const std::string& name) const {
   std::multimap<std::string, std::string>::const_iterator itr =
-    table.find(util::toLower(name));
-  if(itr == table.end()) {
+    table_.find(util::toLower(name));
+  if(itr == table_.end()) {
     return A2STR::NIL;
   } else {
     return (*itr).second;
@@ -111,7 +124,7 @@ std::vector<std::string> HttpHeader::get(const std::string& name) const
   std::string n(util::toLower(name));
   std::pair<std::multimap<std::string, std::string>::const_iterator,
     std::multimap<std::string, std::string>::const_iterator> itrpair =
-    table.equal_range(n);
+    table_.equal_range(n);
   std::multimap<std::string, std::string>::const_iterator first = itrpair.first;
   while(first != itrpair.second) {
     v.push_back((*first).second);
@@ -145,7 +158,8 @@ RangeHandle HttpHeader::getRange() const
       if(contentLength == 0) {
         return SharedHandle<Range>(new Range());
       } else {
-        return SharedHandle<Range>(new Range(0, contentLength-1, contentLength));
+        return SharedHandle<Range>
+          (new Range(0, contentLength-1, contentLength));
       }
     }
   }
@@ -155,7 +169,7 @@ RangeHandle HttpHeader::getRange() const
     // but some server returns '100-199/100', omitting bytes-unit sepcifier
     // 'bytes'.
     std::pair<std::string, std::string> splist;
-    util::split(splist, rangeStr, ' ');
+    util::divide(splist, rangeStr, ' ');
     if(splist.second.empty()) {
       // we assume bytes-unit specifier omitted.
       byteRangeSpec = splist.first;
@@ -164,10 +178,10 @@ RangeHandle HttpHeader::getRange() const
     }
   }
   std::pair<std::string, std::string> byteRangeSpecPair;
-  util::split(byteRangeSpecPair, byteRangeSpec, '/');
+  util::divide(byteRangeSpecPair, byteRangeSpec, '/');
 
   std::pair<std::string, std::string> byteRangeRespSpecPair;
-  util::split(byteRangeRespSpecPair, byteRangeSpecPair.first, '-');
+  util::divide(byteRangeRespSpecPair, byteRangeSpecPair.first, '-');
 
   off_t startByte = util::parseLLInt(byteRangeRespSpecPair.first);
   off_t endByte = util::parseLLInt(byteRangeRespSpecPair.second);
@@ -178,41 +192,41 @@ RangeHandle HttpHeader::getRange() const
 
 void HttpHeader::setResponseStatus(const std::string& responseStatus)
 {
-  _responseStatus = responseStatus;
+  responseStatus_ = responseStatus;
 }
 
 void HttpHeader::setVersion(const std::string& version)
 {
-  _version = version;
+  version_ = version;
 }
 
 void HttpHeader::setMethod(const std::string& method)
 {
-  _method = method;
+  method_ = method;
 }
 
 void HttpHeader::setRequestPath(const std::string& requestPath)
 {
-  _requestPath = requestPath;
+  requestPath_ = requestPath;
 }
 
 void HttpHeader::fill(std::istream& in)
 {
   std::string line;
   while(std::getline(in, line)) {
-    line = util::trim(line);
+    line = util::strip(line);
     if(line.empty()) {
       continue;
     }
     std::pair<std::string, std::string> hp;
-    util::split(hp, line, ':');
+    util::divide(hp, line, ':');
     put(hp.first, hp.second);
   }
 }
 
 void HttpHeader::clearField()
 {
-  table.clear();
+  table_.clear();
 }
 
 } // namespace aria2
