@@ -48,14 +48,14 @@ namespace aria2 {
 class HttpRequest;
 class HttpHeader;
 class Logger;
-class Decoder;
+class StreamFilter;
 
 class HttpResponse {
 private:
-  cuid_t cuid;
-  SharedHandle<HttpRequest> httpRequest;
-  SharedHandle<HttpHeader> httpHeader;
-  Logger* logger;
+  cuid_t cuid_;
+  SharedHandle<HttpRequest> httpRequest_;
+  SharedHandle<HttpHeader> httpHeader_;
+  Logger* logger_;
 public:
   HttpResponse();
   
@@ -86,13 +86,13 @@ public:
 
   std::string getTransferEncoding() const;
 
-  SharedHandle<Decoder> getTransferEncodingDecoder() const;
+  SharedHandle<StreamFilter> getTransferEncodingStreamFilter() const;
 
   bool isContentEncodingSpecified() const;
 
   const std::string& getContentEncoding() const;
 
-  SharedHandle<Decoder> getContentEncodingDecoder() const;
+  SharedHandle<StreamFilter> getContentEncodingStreamFilter() const;
 
   uint64_t getContentLength() const;
 
@@ -105,7 +105,7 @@ public:
 
   const SharedHandle<HttpHeader>& getHttpHeader() const
   {
-    return httpHeader;
+    return httpHeader_;
   }
 
   const std::string& getResponseStatus() const;
@@ -114,12 +114,12 @@ public:
 
   const SharedHandle<HttpRequest>& getHttpRequest() const
   {
-    return httpRequest;
+    return httpRequest_;
   }
 
   void setCuid(cuid_t cuid)
   {
-    this->cuid = cuid;
+    cuid_ = cuid;
   }
 
   bool hasRetryAfter() const;
