@@ -36,37 +36,42 @@
 #include "DownloadEngine.h"
 #include "BtRuntime.h"
 #include "PeerStorage.h"
+#include "RequestGroupMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
+#include "ServerStatMan.h"
+#include "FileEntry.h"
 
 namespace aria2 {
 
 PeerChokeCommand::PeerChokeCommand(cuid_t cuid,
                                    DownloadEngine* e):
   Command(cuid),
-  e(e) {}
+  e_(e) {}
 
 PeerChokeCommand::~PeerChokeCommand() {}
 
 bool PeerChokeCommand::execute() {
-  if(_btRuntime->isHalt()) {
+  if(btRuntime_->isHalt()) {
     return true;
   }
-  if(_peerStorage->chokeRoundIntervalElapsed()) {
-    _peerStorage->executeChoke();
+  if(peerStorage_->chokeRoundIntervalElapsed()) {
+    peerStorage_->executeChoke();
   }
-  e->commands.push_back(this);
+  e_->addCommand(this);
   return false;
 }
 
 void PeerChokeCommand::setBtRuntime
 (const SharedHandle<BtRuntime>& btRuntime)
 {
-  _btRuntime = btRuntime;
+  btRuntime_ = btRuntime;
 }
 
 void PeerChokeCommand::setPeerStorage
 (const SharedHandle<PeerStorage>& peerStorage)
 {
-  _peerStorage = peerStorage;
+  peerStorage_ = peerStorage;
 }
 
 } // namespace aria2
