@@ -48,29 +48,36 @@
 #include "SimpleRandomizer.h"
 #include "FileEntry.h"
 #include "util.h"
+#include "ServerStatMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
 
 namespace aria2 {
 
-unsigned int PeerListenCommand::__numInstance = 0;
+unsigned int PeerListenCommand::numInstance_ = 0;
 
-PeerListenCommand* PeerListenCommand::__instance = 0;
+PeerListenCommand* PeerListenCommand::instance_ = 0;
 
-PeerListenCommand::PeerListenCommand(cuid_t cuid, DownloadEngine* e):
+PeerListenCommand* PeerListenCommand::instance6_ = 0;
+
+PeerListenCommand::PeerListenCommand
+(cuid_t cuid, DownloadEngine* e, int family):
   Command(cuid),
-  e(e),
-  _lowestSpeedLimit(20*1024)
+  e_(e),
+  family_(family),
+  lowestSpeedLimit_(20*1024)
 {
-  ++__numInstance;
+  ++numInstance_;
 }
 
 PeerListenCommand::~PeerListenCommand()
 {
-  --__numInstance;
+  --numInstance_;
 }
 
 bool PeerListenCommand::bindPort(uint16_t& port, IntSequence& seq)
 {
-  socket.reset(new SocketCore());
+  socket_.reset(new SocketCore());
 
   std::vector<int32_t> randPorts = seq.flush();
   std::random_shuffle(randPorts.begin(), randPorts.end(),
@@ -83,14 +90,16 @@ bool PeerListenCommand::bindPort(uint16_t& port, IntSequence& seq)
     }
     port = (*portItr);
     try {
-      socket->bind(port);
-      socket->beginListen();
-      socket->setNonBlockingMode();
-      logger->notice("BitTorrent: listening to port %d", port);
+      socket_->bind(A2STR::NIL, port, family_);
+      socket_->beginListen();
+      socket_->setNonBlockingMode();
+      getLogger()->notice("IPv%d BitTorrent: listening to port %d",
+                          family_ == AF_INET?4:6, port);
       return true;
     } catch(RecoverableException& ex) {
-      logger->error(MSG_BIND_FAILURE, ex, util::itos(cuid).c_str(), port);
-      socket->closeConnection();
+      getLogger()->error(MSG_BIND_FAILURE, ex,
+                         util::itos(getCuid()).c_str(), port);
+      socket_->closeConnection();
     }
   }
   return false;
@@ -98,54 +107,63 @@ bool PeerListenCommand::bindPort(uint16_t& port, IntSequence& seq)
 
 uint16_t PeerListenCommand::getPort() const
 {
-  if(socket.isNull()) {
+  if(socket_.isNull()) {
     return 0;
   } else {
     std::pair<std::string, uint16_t> addr;
-    socket->getAddrInfo(addr);
+    socket_->getAddrInfo(addr);
     return addr.second;
   }
 }
 
 bool PeerListenCommand::execute() {
-  if(e->isHaltRequested() || e->_requestGroupMan->downloadFinished()) {
+  if(e_->isHaltRequested() || e_->getRequestGroupMan()->downloadFinished()) {
     return true;
   }
-  for(int i = 0; i < 3 && socket->isReadable(0); ++i) {
+  for(int i = 0; i < 3 && socket_->isReadable(0); ++i) {
     SocketHandle peerSocket;
     try {
-      peerSocket.reset(socket->acceptConnection());
+      peerSocket.reset(socket_->acceptConnection());
       std::pair<std::string, uint16_t> peerInfo;
       peerSocket->getPeerInfo(peerInfo);
 
       peerSocket->setNonBlockingMode();
 
       SharedHandle<Peer> peer(new Peer(peerInfo.first, peerInfo.second, true));
-      cuid_t cuid = e->newCUID();
+      cuid_t cuid = e_->newCUID();
       Command* command =
-        new ReceiverMSEHandshakeCommand(cuid, peer, e, peerSocket);
-      e->commands.push_back(command);
-      if(logger->debug()) {
-        logger->debug("Accepted the connection from %s:%u.",
-                      peer->ipaddr.c_str(),
-                      peer->port);
-        logger->debug("Added CUID#%s to receive BitTorrent/MSE handshake.",
-                      util::itos(cuid).c_str());
+        new ReceiverMSEHandshakeCommand(cuid, peer, e_, peerSocket);
+      e_->addCommand(command);
+      if(getLogger()->debug()) {
+        getLogger()->debug("Accepted the connection from %s:%u.",
+                           peer->getIPAddress().c_str(),
+                           peer->getPort());
+        getLogger()->debug("Added CUID#%s to receive BitTorrent/MSE handshake.",
+                           util::itos(cuid).c_str());
       }
     } catch(RecoverableException& ex) {
-      logger->debug(MSG_ACCEPT_FAILURE, ex, util::itos(cuid).c_str());
+      getLogger()->debug(MSG_ACCEPT_FAILURE, ex, util::itos(getCuid()).c_str());
     }               
   }
-  e->commands.push_back(this);
+  e_->addCommand(this);
   return false;
 }
 
-PeerListenCommand* PeerListenCommand::getInstance(DownloadEngine* e)
+PeerListenCommand* PeerListenCommand::getInstance(DownloadEngine* e, int family)
 {
-  if(__numInstance == 0) {
-    __instance = new PeerListenCommand(e->newCUID(), e);
+  if(family == AF_INET) {
+    if(!instance_) {
+      instance_ = new PeerListenCommand(e->newCUID(), e, family);
+    }
+    return instance_;
+  } else if(family == AF_INET6) {
+    if(!instance6_) {
+      instance6_ = new PeerListenCommand(e->newCUID(), e, family);
+    }
+    return instance6_;
+  } else {
+    return 0;
   }
-  return __instance;
 }
 
 } // namespace aria2
