@@ -40,6 +40,7 @@
 namespace aria2 {
 
 class BinaryStream;
+class Logger;
 
 class SingleFileAllocationIterator:public FileAllocationIterator
 {
@@ -51,6 +52,8 @@ private:
   uint64_t totalLength_;
 
   unsigned char* buffer_;
+
+  Logger* logger_;
 public:
   SingleFileAllocationIterator(BinaryStream* stream, off_t offset, uint64_t totalLength);
 
@@ -76,8 +79,6 @@ public:
   void init();
 };
 
-typedef SharedHandle<SingleFileAllocationIterator> SingleFileAllocationIteratorHandle;
-
 } // namespace aria2
 
 #endif // _D_SINGLE_FILE_ALLOCATION_ITERATOR_H_
