@@ -61,82 +61,86 @@
 #include "bittorrent_helper.h"
 #include "a2functional.h"
 #include "util.h"
+#include "RequestGroupMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
+#include "ServerStatMan.h"
 
 namespace aria2 {
 
 TrackerWatcherCommand::TrackerWatcherCommand
 (cuid_t cuid, RequestGroup* requestGroup, DownloadEngine* e):
   Command(cuid),
-  _requestGroup(requestGroup),
-  e(e)
+  requestGroup_(requestGroup),
+  e_(e)
 {
-  _requestGroup->increaseNumCommand();
+  requestGroup_->increaseNumCommand();
 }
 
 TrackerWatcherCommand::~TrackerWatcherCommand()
 {
-  _requestGroup->decreaseNumCommand();
+  requestGroup_->decreaseNumCommand();
 }
 
 bool TrackerWatcherCommand::execute() {
-  if(_requestGroup->isForceHaltRequested()) {
-    if(_trackerRequestGroup.isNull()) {
+  if(requestGroup_->isForceHaltRequested()) {
+    if(trackerRequestGroup_.isNull()) {
       return true;
-    } else if(_trackerRequestGroup->getNumCommand() == 0 ||
-              _trackerRequestGroup->downloadFinished()) {
+    } else if(trackerRequestGroup_->getNumCommand() == 0 ||
+              trackerRequestGroup_->downloadFinished()) {
       return true;
     } else {
-      _trackerRequestGroup->setForceHaltRequested(true);
-      e->commands.push_back(this);
+      trackerRequestGroup_->setForceHaltRequested(true);
+      e_->addCommand(this);
       return false;
     }
   }
-  if(_btAnnounce->noMoreAnnounce()) {
-    if(logger->debug()) {
-      logger->debug("no more announce");
+  if(btAnnounce_->noMoreAnnounce()) {
+    if(getLogger()->debug()) {
+      getLogger()->debug("no more announce");
     }
     return true;
   }
-  if(_trackerRequestGroup.isNull()) {
-    _trackerRequestGroup = createAnnounce();
-    if(!_trackerRequestGroup.isNull()) {
-      std::vector<Command*> commands;
+  if(trackerRequestGroup_.isNull()) {
+    trackerRequestGroup_ = createAnnounce();
+    if(!trackerRequestGroup_.isNull()) {
       try {
-        _trackerRequestGroup->createInitialCommand(commands, e);
+        std::vector<Command*>* commands = new std::vector<Command*>();
+        auto_delete_container<std::vector<Command*> > commandsDel(commands);
+        trackerRequestGroup_->createInitialCommand(*commands, e_);
+        e_->addCommand(*commands);
+        commands->clear();
+        if(getLogger()->debug()) {
+          getLogger()->debug("added tracker request command");
+        }
       } catch(RecoverableException& ex) {
-        logger->error(EX_EXCEPTION_CAUGHT, ex);
-        std::for_each(commands.begin(), commands.end(), Deleter());
-        commands.clear();
-      }
-      e->addCommand(commands);
-      if(logger->debug()) {
-        logger->debug("added tracker request command");
+        getLogger()->error(EX_EXCEPTION_CAUGHT, ex);
       }
     }
-  } else if(_trackerRequestGroup->downloadFinished()){
+  } else if(trackerRequestGroup_->downloadFinished()){
     try {
-      std::string trackerResponse = getTrackerResponse(_trackerRequestGroup);
+      std::string trackerResponse = getTrackerResponse(trackerRequestGroup_);
 
       processTrackerResponse(trackerResponse);
-      _btAnnounce->announceSuccess();
-      _btAnnounce->resetAnnounce();
+      btAnnounce_->announceSuccess();
+      btAnnounce_->resetAnnounce();
     } catch(RecoverableException& ex) {
-      logger->error(EX_EXCEPTION_CAUGHT, ex);      
-      _btAnnounce->announceFailure();
-      if(_btAnnounce->isAllAnnounceFailed()) {
-        _btAnnounce->resetAnnounce();
+      getLogger()->error(EX_EXCEPTION_CAUGHT, ex);      
+      btAnnounce_->announceFailure();
+      if(btAnnounce_->isAllAnnounceFailed()) {
+        btAnnounce_->resetAnnounce();
       }
     }
-    _trackerRequestGroup.reset();
-  } else if(_trackerRequestGroup->getNumCommand() == 0){
+    trackerRequestGroup_.reset();
+  } else if(trackerRequestGroup_->getNumCommand() == 0){
     // handle errors here
-    _btAnnounce->announceFailure(); // inside it, trackers = 0.
-    _trackerRequestGroup.reset();
-    if(_btAnnounce->isAllAnnounceFailed()) {
-      _btAnnounce->resetAnnounce();
+    btAnnounce_->announceFailure(); // inside it, trackers = 0.
+    trackerRequestGroup_.reset();
+    if(btAnnounce_->isAllAnnounceFailed()) {
+      btAnnounce_->resetAnnounce();
     }
   }
-  e->commands.push_back(this);
+  e_->addCommand(this);
   return false;
 }
 
@@ -161,34 +165,34 @@ std::string TrackerWatcherCommand::getTrackerResponse
 void TrackerWatcherCommand::processTrackerResponse
 (const std::string& trackerResponse)
 {
-  _btAnnounce->processAnnounceResponse
+  btAnnounce_->processAnnounceResponse
     (reinterpret_cast<const unsigned char*>(trackerResponse.c_str()),
      trackerResponse.size());
-  while(!_btRuntime->isHalt() && _btRuntime->lessThanMinPeers()) {
-    SharedHandle<Peer> peer = _peerStorage->getUnusedPeer();
+  while(!btRuntime_->isHalt() && btRuntime_->lessThanMinPeers()) {
+    SharedHandle<Peer> peer = peerStorage_->getUnusedPeer();
     if(peer.isNull()) {
       break;
     }
-    peer->usedBy(e->newCUID());
+    peer->usedBy(e_->newCUID());
     PeerInitiateConnectionCommand* command =
       new PeerInitiateConnectionCommand
-      (peer->usedBy(), _requestGroup, peer, e, _btRuntime);
-    command->setPeerStorage(_peerStorage);
-    command->setPieceStorage(_pieceStorage);
-    e->commands.push_back(command);
-    if(logger->debug()) {
-      logger->debug("CUID#%s - Adding new command CUID#%s",
-                    util::itos(cuid).c_str(),
-                    util::itos(peer->usedBy()).c_str());
+      (peer->usedBy(), requestGroup_, peer, e_, btRuntime_);
+    command->setPeerStorage(peerStorage_);
+    command->setPieceStorage(pieceStorage_);
+    e_->addCommand(command);
+    if(getLogger()->debug()) {
+      getLogger()->debug("CUID#%s - Adding new command CUID#%s",
+                         util::itos(getCuid()).c_str(),
+                         util::itos(peer->usedBy()).c_str());
     }
   }
 }
 
 SharedHandle<RequestGroup> TrackerWatcherCommand::createAnnounce() {
   SharedHandle<RequestGroup> rg;
-  if(_btAnnounce->isAnnounceReady()) {
-    rg = createRequestGroup(_btAnnounce->getAnnounceUrl());
-    _btAnnounce->announceStart(); // inside it, trackers++.
+  if(btAnnounce_->isAnnounceReady()) {
+    rg = createRequestGroup(btAnnounce_->getAnnounceUrl());
+    btAnnounce_->announceStart(); // inside it, trackers++.
   }
   return rg;
 }
@@ -196,15 +200,15 @@ SharedHandle<RequestGroup> TrackerWatcherCommand::createAnnounce() {
 static bool backupTrackerIsAvailable
 (const SharedHandle<DownloadContext>& context)
 {
-  const BDE& announceList =
-    context->getAttribute(bittorrent::BITTORRENT)[bittorrent::ANNOUNCE_LIST];
-  if(announceList.size() >= 2) {
+  SharedHandle<TorrentAttribute> torrentAttrs =
+    bittorrent::getTorrentAttrs(context);
+  if(torrentAttrs->announceList.size() >= 2) {
     return true;
   }
-  if(announceList.empty()) {
+  if(torrentAttrs->announceList.empty()) {
     return false;
   }
-  if(announceList[0].size() >= 2) {
+  if(torrentAttrs->announceList[0].size() >= 2) {
     return true;
   } else {
     return false;
@@ -217,25 +221,28 @@ TrackerWatcherCommand::createRequestGroup(const std::string& uri)
   std::vector<std::string> uris;
   uris.push_back(uri);
   SharedHandle<RequestGroup> rg(new RequestGroup(getOption()));
-  if(backupTrackerIsAvailable(_requestGroup->getDownloadContext())) {
-    if(logger->debug()) {
-      logger->debug("This is multi-tracker announce.");
+  if(backupTrackerIsAvailable(requestGroup_->getDownloadContext())) {
+    if(getLogger()->debug()) {
+      getLogger()->debug("This is multi-tracker announce.");
     }
   } else {
-    if(logger->debug()) {
-      logger->debug("This is single-tracker announce.");
+    if(getLogger()->debug()) {
+      getLogger()->debug("This is single-tracker announce.");
     }
   }
+  rg->setNumConcurrentCommand(1);
   // If backup tracker is available, try 2 times for each tracker
   // and if they all fails, then try next one.
   rg->getOption()->put(PREF_MAX_TRIES, "2");
   // TODO When dry-run mode becomes available in BitTorrent, set
   // PREF_DRY_RUN=false too.
-  rg->getOption()->put(PREF_USE_HEAD, V_FALSE);
+  rg->getOption()->put(PREF_USE_HEAD, A2_V_FALSE);
   // Setting tracker timeouts
   rg->setTimeout(rg->getOption()->getAsInt(PREF_BT_TRACKER_TIMEOUT));
   rg->getOption()->put(PREF_CONNECT_TIMEOUT,
                        rg->getOption()->get(PREF_BT_TRACKER_CONNECT_TIMEOUT));
+  rg->getOption()->put(PREF_REUSE_URI, A2_V_FALSE);
+  rg->getOption()->put(PREF_SELECT_LEAST_USED_HOST, A2_V_FALSE);
   static const std::string TRACKER_ANNOUNCE_FILE("[tracker.announce]");
   SharedHandle<DownloadContext> dctx
     (new DownloadContext(getOption()->getAsInt(PREF_SEGMENT_SIZE),
@@ -249,9 +256,9 @@ TrackerWatcherCommand::createRequestGroup(const std::string& uri)
   rg->setFileAllocationEnabled(false);
   rg->setPreLocalFileCheckEnabled(false);
   util::removeMetalinkContentTypes(rg);
-  if(logger->info()) {
-    logger->info("Creating tracker request group GID#%s",
-                 util::itos(rg->getGID()).c_str());
+  if(getLogger()->info()) {
+    getLogger()->info("Creating tracker request group GID#%s",
+                      util::itos(rg->getGID()).c_str());
   }
   return rg;
 }
@@ -259,30 +266,30 @@ TrackerWatcherCommand::createRequestGroup(const std::string& uri)
 void TrackerWatcherCommand::setBtRuntime
 (const SharedHandle<BtRuntime>& btRuntime)
 {
-  _btRuntime = btRuntime;
+  btRuntime_ = btRuntime;
 }
 
 void TrackerWatcherCommand::setPeerStorage
 (const SharedHandle<PeerStorage>& peerStorage)
 {
-  _peerStorage = peerStorage;
+  peerStorage_ = peerStorage;
 }
 
 void TrackerWatcherCommand::setPieceStorage
 (const SharedHandle<PieceStorage>& pieceStorage)
 {
-  _pieceStorage = pieceStorage;
+  pieceStorage_ = pieceStorage;
 }
 
 void TrackerWatcherCommand::setBtAnnounce
 (const SharedHandle<BtAnnounce>& btAnnounce)
 {
-  _btAnnounce = btAnnounce;
+  btAnnounce_ = btAnnounce;
 }
 
 const SharedHandle<Option>& TrackerWatcherCommand::getOption() const
 {
-  return _requestGroup->getOption();
+  return requestGroup_->getOption();
 }
 
 } // namespace aria2
