@@ -52,6 +52,7 @@ namespace aria2 {
 
 class DownloadContext;
 class Randomizer;
+class Option;
 
 namespace bittorrent {
 
@@ -182,18 +183,25 @@ void createPeerMessageString
 (unsigned char* msg, size_t msgLength, size_t payloadLength, uint8_t messageId);
 
 /**
- * Creates compact tracker format(6bytes for ipv4 address and port)
- * and stores the results in compact.
- * compact must be at least 6 bytes and pre-allocated.
- * Returns true if creation is successful, otherwise returns false.
- * The example of failure reason is that addr is not numbers-and-dots
- * notation.
+ * Creates compact form(packed addresss + 2bytes port) and stores the
+ * results in compact.  This function looks addr and if it is IPv4
+ * address, it stores 6bytes in compact and if it is IPv6, it stores
+ * 18bytes in compact.  So compact must be at least 18 bytes and
+ * pre-allocated.  Returns the number of written bytes; for IPv4
+ * address, it is 6 and for IPv6, it is 18. On failure, returns 0.
  */
-bool createcompact
+int packcompact
 (unsigned char* compact, const std::string& addr, uint16_t port);
 
-// Unpack compact into pair of IPv4 address and port.
-std::pair<std::string, uint16_t> unpackcompact(const unsigned char* compact);
+/**
+ * Unpack packed address and port in compact and returns address and
+ * port pair.  family must be AF_INET or AF_INET6.  If family is
+ * AF_INET, first 6 bytes from compact is used.  If family is
+ * AF_INET6, first 18 bytes from compact is used.  On failure, returns
+ * std::pair<std::string, uint16_t>().
+ */
+std::pair<std::string, uint16_t>
+unpackcompact(const unsigned char* compact, int family);
 
 // Throws exception if threshold >= actual
 void assertPayloadLengthGreater
@@ -215,31 +223,55 @@ std::string metadata2Torrent
 // Constructs BitTorrent Magnet URI using attrs.
 std::string torrent2Magnet(const SharedHandle<TorrentAttribute>& attrs);
 
+// Removes announce URI in uris from attrs.  If uris contains '*', all
+// announce URIs are removed.
+void removeAnnounceUri
+(const SharedHandle<TorrentAttribute>& attrs,
+ const std::vector<std::string>& uris);
+
+// Adds announce URI in uris to attrs. Each URI in uris creates its
+// own tier.
+void addAnnounceUri
+(const SharedHandle<TorrentAttribute>& attrs,
+ const std::vector<std::string>& uris);
+
+// This helper function uses 2 option values: PREF_BT_TRACKER and
+// PREF_BT_EXCLUDE_TRACKER. First, the value of
+// PREF_BT_EXCLUDE_TRACKER is converted to std::vector<std::string>
+// and call removeAnnounceUri(). Then the value of PREF_BT_TRACKER is
+// converted to std::vector<std::string> and call addAnnounceUri().
+void adjustAnnounceUri
+(const SharedHandle<TorrentAttribute>& attrs,
+ const SharedHandle<Option>& option);
+
 template<typename OutputIterator>
-void extractPeer(const ValueBase* peerData, OutputIterator dest)
+void extractPeer(const ValueBase* peerData, int family, OutputIterator dest)
 {
   class PeerListValueBaseVisitor:public ValueBaseVisitor {
   private:
     OutputIterator dest_;
+    int family_;
   public:
-    PeerListValueBaseVisitor(OutputIterator dest):dest_(dest) {}
+    PeerListValueBaseVisitor(OutputIterator dest, int family):
+      dest_(dest),
+      family_(family) {}
 
     virtual ~PeerListValueBaseVisitor() {}
 
     virtual void visit(const String& peerData)
     {
+      int unit = family_ == AF_INET?6:18;
       size_t length = peerData.s().size();
-      if(length%6 == 0) {
-        const char* base = peerData.s().data();
-        for(size_t i = 0; i < length; i += 6) {
-          struct in_addr in;
-          memcpy(&in.s_addr, base+i, sizeof(uint32_t));
-          std::string ipaddr = inet_ntoa(in);
-          uint16_t port_nworder;
-          memcpy(&port_nworder, base+i+4, sizeof(uint16_t));
-          uint16_t port = ntohs(port_nworder);
-          *dest_ = SharedHandle<Peer>(new Peer(ipaddr, port));
-          ++dest_;
+      if(length%unit == 0) {
+        const unsigned char* base =
+          reinterpret_cast<const unsigned char*>(peerData.s().data());
+        const unsigned char* end = base+length;
+        for(; base != end; base += unit) {
+          std::pair<std::string, uint16_t> p = unpackcompact(base, family_);
+          if(p.first.empty()) {
+            continue;
+          }
+          *dest_++ = SharedHandle<Peer>(new Peer(p.first, p.second));
         }
       }
     }
@@ -269,17 +301,20 @@ void extractPeer(const ValueBase* peerData, OutputIterator dest)
     virtual void visit(const Dict& v) {}
   };
   if(peerData) {
-    PeerListValueBaseVisitor visitor(dest);
+    PeerListValueBaseVisitor visitor(dest, family);
     peerData->accept(visitor);
   }
 }
 
 template<typename OutputIterator>
-void extractPeer(const SharedHandle<ValueBase>& peerData, OutputIterator dest)
+void extractPeer
+(const SharedHandle<ValueBase>& peerData, int family, OutputIterator dest)
 {
-  return extractPeer(peerData.get(), dest);
+  return extractPeer(peerData.get(), family, dest);
 }
 
+int getCompactLength(int family);
+
 } // namespace bittorrent
 
 } // namespace aria2
