@@ -38,10 +38,10 @@
 #include <unistd.h>
 #include <getopt.h>
 
-#include <deque>
 #include <fstream>
 #include <iostream>
 #include <numeric>
+#include <vector>
 
 #include "SharedHandle.h"
 #include "LogFactory.h"
@@ -121,9 +121,9 @@ static void showTorrentFile(const std::string& uri)
 static void showMetalinkFile
 (const std::string& uri, const SharedHandle<Option>& op)
 {
-  std::deque<SharedHandle<MetalinkEntry> > metalinkEntries;
+  std::vector<SharedHandle<MetalinkEntry> > metalinkEntries;
   MetalinkHelper::parseAndQuery(metalinkEntries, uri, op.get());
-  std::deque<SharedHandle<FileEntry> > fileEntries;
+  std::vector<SharedHandle<FileEntry> > fileEntries;
   MetalinkEntry::toFileEntry(fileEntries, metalinkEntries);
   util::toStream(fileEntries.begin(), fileEntries.end(), std::cout);
   std::cout << std::endl;
@@ -132,11 +132,11 @@ static void showMetalinkFile
 
 #if defined ENABLE_BITTORRENT || defined ENABLE_METALINK
 static void showFiles
-(const std::deque<std::string>& uris, const SharedHandle<Option>& op)
+(const std::vector<std::string>& uris, const SharedHandle<Option>& op)
 {
   ProtocolDetector dt;
-  for(std::deque<std::string>::const_iterator i = uris.begin();
-      i != uris.end(); ++i) {
+  for(std::vector<std::string>::const_iterator i = uris.begin(),
+        eoi = uris.end(); i != eoi; ++i) {
     printf(">>> ");
     printf(MSG_SHOW_FILES, (*i).c_str());
     printf("\n");
@@ -162,12 +162,12 @@ static void showFiles
 }
 #endif // ENABLE_BITTORRENT || ENABLE_METALINK
 
-extern void option_processing(Option& option, std::deque<std::string>& uris,
+extern void option_processing(Option& option, std::vector<std::string>& uris,
                               int argc, char* const argv[]);
 
 downloadresultcode::RESULT main(int argc, char* argv[])
 {
-  std::deque<std::string> args;
+  std::vector<std::string> args;
   SharedHandle<Option> op(new Option());
   option_processing(*op.get(), args, argc, argv);
 
@@ -175,27 +175,12 @@ downloadresultcode::RESULT main(int argc, char* argv[])
 #ifdef ENABLE_BITTORRENT
   bittorrent::generateStaticPeerId(op->get(PREF_PEER_ID_PREFIX));
 #endif // ENABLE_BITTORRENT
-  if(op->get(PREF_LOG) == "-") {
-    LogFactory::setLogFile(DEV_STDOUT);
-  } else if(op->blank(PREF_LOG)) {
-    LogFactory::setLogFile(DEV_NULL);
-  } else {
-    LogFactory::setLogFile(op->get(PREF_LOG));
-  }
+  LogFactory::setLogFile(op->get(PREF_LOG));
   LogFactory::setLogLevel(op->get(PREF_LOG_LEVEL));
   if(op->getAsBool(PREF_QUIET)) {
     LogFactory::setConsoleOutput(false);
   }
-#ifdef HAVE_EPOLL
-  if(op->get(PREF_EVENT_POLL) == V_EPOLL) {
-    SocketCore::useEpoll();
-  } else
-#endif // HAVE_EPOLL
-    if(op->get(PREF_EVENT_POLL) == V_SELECT) {
-      SocketCore::useSelect();
-    }
   downloadresultcode::RESULT exitStatus = downloadresultcode::FINISHED;
-
   Logger* logger = LogFactory::getInstance();
   logger->info("<<--- --- --- ---");
   logger->info("  --- --- --- ---");
@@ -227,10 +212,10 @@ downloadresultcode::RESULT main(int argc, char* argv[])
   // died.
   util::setGlobalSignalHandler(SIGCHLD, SIG_IGN, 0);
 #endif // SIGCHILD
-  std::deque<SharedHandle<RequestGroup> > requestGroups;
+  std::vector<SharedHandle<RequestGroup> > requestGroups;
 #ifdef ENABLE_BITTORRENT
   if(!op->blank(PREF_TORRENT_FILE)) {
-    if(op->get(PREF_SHOW_FILES) == V_TRUE) {
+    if(op->get(PREF_SHOW_FILES) == A2_V_TRUE) {
       showTorrentFile(op->get(PREF_TORRENT_FILE));
       return exitStatus;
     } else {
@@ -241,7 +226,7 @@ downloadresultcode::RESULT main(int argc, char* argv[])
 #endif // ENABLE_BITTORRENT
 #ifdef ENABLE_METALINK
     if(!op->blank(PREF_METALINK_FILE)) {
-      if(op->get(PREF_SHOW_FILES) == V_TRUE) {
+      if(op->get(PREF_SHOW_FILES) == A2_V_TRUE) {
         showMetalinkFile(op->get(PREF_METALINK_FILE), op);
         return exitStatus;
       } else {
@@ -253,7 +238,7 @@ downloadresultcode::RESULT main(int argc, char* argv[])
       if(!op->blank(PREF_INPUT_FILE)) {
         createRequestGroupForUriList(requestGroups, op);
 #if defined ENABLE_BITTORRENT || defined ENABLE_METALINK
-      } else if(op->get(PREF_SHOW_FILES) == V_TRUE) {
+      } else if(op->get(PREF_SHOW_FILES) == A2_V_TRUE) {
         showFiles(args, op);
         return exitStatus;
 #endif // ENABLE_METALINK || ENABLE_METALINK
