@@ -74,10 +74,11 @@
 #include "StringFormat.h"
 #include "A2STR.h"
 #include "array_fun.h"
-#include "a2functional.h"
 #include "bitfield.h"
 #include "DownloadHandlerConstants.h"
 #include "RequestGroup.h"
+#include "LogFactory.h"
+#include "Option.h"
 #ifdef ENABLE_MESSAGE_DIGEST
 # include "MessageDigestHelper.h"
 #endif // ENABLE_MESSAGE_DIGEST
@@ -91,57 +92,28 @@ namespace aria2 {
 
 namespace util {
 
-const std::string DEFAULT_TRIM_CHARSET("\r\n\t ");
+const std::string DEFAULT_STRIP_CHARSET("\r\n\t ");
 
-std::string trim(const std::string& src, const std::string& trimCharset)
+std::string strip(const std::string& str, const std::string& chars)
 {
-  std::string temp(src);
-  trimSelf(temp, trimCharset);
-  return temp;
+  return stripIter(str.begin(), str.end(), chars);
 }
 
-void trimSelf(std::string& str, const std::string& trimCharset)
+void divide
+(std::pair<std::string, std::string>& hp, const std::string& src, char delim)
 {
-  std::string::size_type first = str.find_first_not_of(trimCharset);
-  if(first == std::string::npos) {
-    str.clear();
-  } else {
-    std::string::size_type last = str.find_last_not_of(trimCharset)+1;
-    str.erase(last);
-    str.erase(0, first);
-  }
-}
-
-void split(std::pair<std::string, std::string>& hp, const std::string& src, char delim)
-{
-  hp.first = A2STR::NIL;
-  hp.second = A2STR::NIL;
-  std::string::size_type p = src.find(delim);
-  if(p == std::string::npos) {
-    hp.first = trim(src);
+  std::string::const_iterator first = src.begin();
+  std::string::const_iterator last = src.end();
+  std::string::const_iterator dpos = std::find(first, last, delim);
+  if(dpos == last) {
+    hp.first = strip(src);
     hp.second = A2STR::NIL;
   } else {
-    hp.first = trim(src.substr(0, p));
-    hp.second = trim(src.substr(p+1));
+    hp.first = stripIter(first, dpos);
+    hp.second = stripIter(dpos+1, last);
   }
 }
 
-std::pair<std::string, std::string> split(const std::string& src, const std::string& delims)
-{
-  std::pair<std::string, std::string> hp;
-  hp.first = A2STR::NIL;
-  hp.second = A2STR::NIL;
-  std::string::size_type p = src.find_first_of(delims);
-  if(p == std::string::npos) {
-    hp.first = trim(src);
-    hp.second = A2STR::NIL;
-  } else {
-    hp.first = trim(src.substr(0, p));
-    hp.second = trim(src.substr(p+1));
-  }
-  return hp;
-}
-
 std::string itos(int64_t value, bool comma)
 {
   bool flag = false;
@@ -289,13 +261,81 @@ bool inRFC2616HttpToken(const char c)
     std::find(vbegin(chars), vend(chars), c) != vend(chars);
 }
 
-std::string percentEncode(const unsigned char* target, size_t len) {
+namespace {
+bool isUtf8Tail(unsigned char ch)
+{
+  return in(ch, 0x80u, 0xbfu);
+}
+}
+
+bool isUtf8(const std::string& str)
+{
+  for(std::string::const_iterator s = str.begin(), eos = str.end(); s != eos;
+      ++s) {
+    unsigned char firstChar = *s;
+    // See ABNF in http://tools.ietf.org/search/rfc3629#section-4
+    if(in(firstChar, 0x20u, 0x7eu) ||
+       firstChar == 0x09u || firstChar == 0x0au ||firstChar == 0x0du) {
+      // UTF8-1 (without ctrl chars)
+    } else if(in(firstChar, 0xc2u, 0xdfu)) {
+       // UTF8-2
+      if(++s == eos || !isUtf8Tail(*s)) {
+        return false;
+      }
+    } else if(0xe0u == firstChar) {
+      // UTF8-3
+      if(++s == eos || !in(static_cast<unsigned char>(*s), 0xa0u, 0xbfu) ||
+         ++s == eos || !isUtf8Tail(*s)) {
+        return false;
+      }
+    } else if(in(firstChar, 0xe1u, 0xecu) || in(firstChar, 0xeeu, 0xefu)) {
+      // UTF8-3
+      if(++s == eos || !isUtf8Tail(*s) ||
+         ++s == eos || !isUtf8Tail(*s)) {
+        return false;
+      }
+    } else if(0xedu == firstChar) {
+      // UTF8-3
+      if(++s == eos || !in(static_cast<unsigned char>(*s), 0x80u, 0x9fu) ||
+         ++s == eos || !isUtf8Tail(*s)) {
+        return false;
+      } 
+    } else if(0xf0u == firstChar) {
+      // UTF8-4
+      if(++s == eos || !in(static_cast<unsigned char>(*s), 0x90u, 0xbfu) ||
+         ++s == eos || !isUtf8Tail(*s) ||
+         ++s == eos || !isUtf8Tail(*s)) {
+        return false;
+      }
+    } else if(in(firstChar, 0xf1u, 0xf3u)) {
+      // UTF8-4
+      if(++s == eos || !isUtf8Tail(*s) ||
+         ++s == eos || !isUtf8Tail(*s) ||
+         ++s == eos || !isUtf8Tail(*s)) {
+        return false;
+      }
+    } else if(0xf4u == firstChar) {
+      // UTF8-4
+      if(++s == eos || !in(static_cast<unsigned char>(*s), 0x80u, 0x8fu) ||
+         ++s == eos || !isUtf8Tail(*s) ||
+         ++s == eos || !isUtf8Tail(*s)) {
+        return false;
+      }
+    } else {
+      return false;
+    }
+  }
+  return true;
+}
+
+std::string percentEncode(const unsigned char* target, size_t len)
+{
   std::string dest;
   for(size_t i = 0; i < len; ++i) {
-    if(!inRFC3986UnreservedChars(target[i])) {
-      dest.append(StringFormat("%%%02X", target[i]).str());
-    } else {
+    if(inRFC3986UnreservedChars(target[i])) {
       dest += target[i];
+    } else {
+      dest.append(StringFormat("%%%02X", target[i]).str());
     }
   }
   return dest;
@@ -304,7 +344,7 @@ std::string percentEncode(const unsigned char* target, size_t len) {
 std::string percentEncode(const std::string& target)
 {
   return percentEncode(reinterpret_cast<const unsigned char*>(target.c_str()),
-                   target.size());
+                       target.size());
 }
 
 std::string torrentPercentEncode(const unsigned char* target, size_t len) {
@@ -350,7 +390,7 @@ std::string toHex(const unsigned char* src, size_t len) {
   const unsigned char* last = src+len;
   for(const unsigned char* i = src; i != last; ++i) {
     *o = (*i >> 4);
-    *(o+1) = (*i)&0x0f;
+    *(o+1) = (*i)&0x0fu;
     for(int j = 0; j < 2; ++j) {
       if(*o < 10) {
         *o += '0';
@@ -481,7 +521,8 @@ uint32_t parseUInt(const std::string& s, int base)
 
 bool parseUIntNoThrow(uint32_t& result, const std::string& s, int base)
 {
-  std::string trimed = trim(s);
+  // TODO what happens when we don't trim s?
+  std::string trimed = strip(s);
   if(trimed.empty()) {
     return false;
   }
@@ -503,7 +544,7 @@ bool parseUIntNoThrow(uint32_t& result, const std::string& s, int base)
 
 int64_t parseLLInt(const std::string& s, int32_t base)
 {
-  std::string trimed = trim(s);
+  std::string trimed = strip(s);
   if(trimed.empty()) {
     throw DL_ABORT_EX(StringFormat(MSG_STRING_INTEGER_CONVERSION_FAILURE,
                                    "empty string").str());
@@ -521,9 +562,27 @@ int64_t parseLLInt(const std::string& s, int32_t base)
   return v;
 }
 
+bool parseLLIntNoThrow(int64_t& result, const std::string& s, int base)
+{
+  std::string trimed = strip(s);
+  if(trimed.empty()) {
+    return false;
+  }
+  char* stop;
+  errno = 0;
+  int64_t v = strtoll(trimed.c_str(), &stop, base);
+  if(*stop != '\0') {
+    return false;
+  } else if(((v == INT64_MIN) || (v == INT64_MAX)) && (errno == ERANGE)) {
+    return false;
+  }
+  result = v;
+  return true;
+}
+
 uint64_t parseULLInt(const std::string& s, int base)
 {
-  std::string trimed = trim(s);
+  std::string trimed = strip(s);
   if(trimed.empty()) {
     throw DL_ABORT_EX(StringFormat(MSG_STRING_INTEGER_CONVERSION_FAILURE,
                                    "empty string").str());
@@ -551,7 +610,8 @@ IntSequence parseIntRange(const std::string& src)
   IntSequence::Values values;
   std::string temp = src;
   while(temp.size()) {
-    std::pair<std::string, std::string> p = split(temp, ",");
+    std::pair<std::string, std::string> p;
+    divide(p, temp, ',');
     temp = p.second;
     if(p.first.empty()) {
       continue;
@@ -560,7 +620,8 @@ IntSequence parseIntRange(const std::string& src)
       int32_t v = parseInt(p.first.c_str());
       values.push_back(IntSequence::Value(v, v+1));
     } else {
-      std::pair<std::string, std::string> vp = split(p.first.c_str(), "-");
+      std::pair<std::string, std::string> vp;
+      divide(vp, p.first.c_str(), '-');
       if(vp.first.empty() || vp.second.empty()) {
         throw DL_ABORT_EX
           (StringFormat(MSG_INCOMPLETE_RANGE, p.first.c_str()).str());
@@ -663,14 +724,14 @@ std::string iso8859ToUtf8(const std::string& src)
   for(std::string::const_iterator itr = src.begin(), eoi = src.end();
       itr != eoi; ++itr) {
     unsigned char c = *itr;
-    if(0xa0 <= c) {
-      if(c <= 0xbf) {
-        dest += 0xc2;
+    if(0xa0u <= c) {
+      if(c <= 0xbfu) {
+        dest += 0xc2u;
       } else {
-        dest += 0xc3;
+        dest += 0xc3u;
       }
-      dest += c&(~0x40);
-    } else if(0x80 <= c && c <= 0x9f) {
+      dest += c&(~0x40u);
+    } else if(0x80u <= c && c <= 0x9fu) {
       return A2STR::NIL;
     } else {
       dest += c;
@@ -708,7 +769,7 @@ static void parseParam(OutputIterator out, const std::string& header)
         param = std::string(paramFirst, paramLast);
       }
     }
-    trimSelf(param);
+    param = strip(param);
     *out++ = param;
     if(paramLast == eoi) {
       break;
@@ -742,7 +803,7 @@ std::string getContentDispositionFilename(const std::string& header)
         continue;
       }
       std::pair<std::string, std::string> paramPair;
-      split(paramPair, param, '=');
+      divide(paramPair, param, '=');
       std::string value = paramPair.second;
       std::vector<std::string> extValues;
       split(value, std::back_inserter(extValues), "'", false, true);
@@ -802,7 +863,7 @@ std::string getContentDispositionFilename(const std::string& header)
         continue;
       }
       std::pair<std::string, std::string> paramPair;
-      split(paramPair, param, '=');
+      divide(paramPair, param, '=');
       std::string value = paramPair.second;
       if(value.empty()) {
         continue;
@@ -818,7 +879,7 @@ std::string getContentDispositionFilename(const std::string& header)
       }
       static const std::string TRIMMED("\r\n\t '\"");
       value = percentDecode(std::string(value.begin(), filenameLast));
-      trimSelf(value, TRIMMED);
+      value = strip(value, TRIMMED);
       value.erase(std::remove(value.begin(), value.end(), '\\'), value.end());
       if(!detectDirTraversal(value) &&
          value.find(A2STR::SLASH_C) == std::string::npos) {
@@ -852,6 +913,16 @@ std::string toLower(const std::string& src) {
   return temp;
 }
 
+void uppercase(std::string& s)
+{
+  std::transform(s.begin(), s.end(), s.begin(), ::toupper);
+}
+
+void lowercase(std::string& s)
+{
+  std::transform(s.begin(), s.end(), s.begin(), ::tolower);
+}
+
 bool isNumericHost(const std::string& name)
 {
   struct addrinfo hints;
@@ -923,10 +994,10 @@ std::string abbrevSize(int64_t size)
   char units[] = { 'K', 'M' };
   size_t numUnit = sizeof(units)/sizeof(char);
   size_t i = 0;
-  int r = size&0x3ff;
+  int r = size&0x3ffu;
   size >>= 10;
   for(; i < numUnit-1 && size >= 1024; ++i) {
-    r = size&0x3ff;
+    r = size&0x3ffu;
     size >>= 10;
   }
   std::string result = itos(size, true);
@@ -1049,13 +1120,7 @@ unsigned int alphaToNum(const std::string& alphabets)
 void mkdirs(const std::string& dirpath)
 {
   File dir(dirpath);
-  if(dir.isDir()) {
-    // do nothing
-  } else if(dir.exists()) {
-    throw DL_ABORT_EX
-      (StringFormat(EX_MAKE_DIR, dir.getPath().c_str(),
-                    "File already exists.").str());
-  } else if(!dir.mkdirs()) {
+  if(!dir.mkdirs() &&!dir.isDir()) {
     throw DL_ABORT_EX
       (StringFormat(EX_MAKE_DIR, dir.getPath().c_str(),
                     strerror(errno)).str());
@@ -1144,7 +1209,8 @@ std::string htmlEscape(const std::string& src)
 std::map<size_t, std::string>::value_type
 parseIndexPath(const std::string& line)
 {
-  std::pair<std::string, std::string> p = split(line, "=");
+  std::pair<std::string, std::string> p;
+  divide(p, line, '=');
   size_t index = parseUInt(p.first);
   if(p.second.empty()) {
     throw DL_ABORT_EX(StringFormat("Path with index=%u is empty.",
@@ -1213,7 +1279,8 @@ std::string applyDir(const std::string& dir, const std::string& relPath)
 
 std::string fixTaintedBasename(const std::string& src)
 {
-  return escapePath(replace(src, A2STR::SLASH_C, A2STR::UNDERSCORE_C));
+  static std::string SLASH_REP = "%2F";
+  return escapePath(replace(src, A2STR::SLASH_C, SLASH_REP));
 }
 
 void generateRandomKey(unsigned char* key)
@@ -1253,51 +1320,55 @@ bool inPrivateAddress(const std::string& ipv4addr)
 bool detectDirTraversal(const std::string& s)
 {
   for(std::string::const_iterator i = s.begin(), eoi = s.end(); i != eoi; ++i) {
-    if(0x00 <= (*i) && (*i) <= 0x1f) {
+    unsigned char c = *i;
+    if(in(c, 0x00u, 0x1fu) || c == 0x7fu) {
       return true;
     }
   }
+
+  static std::string DS = "./";
+  static std::string DDS = "../";
+  static std::string SD = "/.";
+  static std::string SDD = "/..";
+  static std::string SDDS = "/../";
+  static std::string SDS = "/./";
+  static std::string DD = "..";
+
   return s == A2STR::DOT_C ||
-    s == ".." ||
+    s == DD ||
     util::startsWith(s, A2STR::SLASH_C) ||
-    util::startsWith(s, "./") ||
-    util::startsWith(s, "../") ||
-    s.find("/../") != std::string::npos ||
-    s.find("/./") != std::string::npos ||
-    util::endsWith(s, "/") ||
-    util::endsWith(s, "/.") ||
-    util::endsWith(s, "/..");
-}
-
-namespace {
-class EscapePath {
-private:
-  char repChar_;
-public:
-  EscapePath(const char& repChar):repChar_(repChar) {}
-
-  char operator()(const char& c) {
-    if(0x00 <= c && c <=0x1f) {
-      return repChar_;
-    }
-#ifdef __MINGW32__
-    // We don't escape '/' because we use it as a path separator.
-    static const char WIN_INVALID_PATH_CHARS[] =
-      { '"', '*', ':', '<', '>', '?', '\\', '|' };
-    if(std::find(vbegin(WIN_INVALID_PATH_CHARS), vend(WIN_INVALID_PATH_CHARS),
-                 c) != vend(WIN_INVALID_PATH_CHARS)) {
-      return repChar_;
-    }
-#endif // __MINGW32__
-    return c;
-  }
-};
+    util::startsWith(s, DS) ||
+    util::startsWith(s, DDS) ||
+    s.find(SDDS) != std::string::npos ||
+    s.find(SDS) != std::string::npos ||
+    util::endsWith(s, A2STR::SLASH_C) ||
+    util::endsWith(s, SD) ||
+    util::endsWith(s, SDD);
 }
 
 std::string escapePath(const std::string& s)
 {
-  std::string d = s;
-  std::transform(d.begin(), d.end(), d.begin(), EscapePath('_'));
+  // We don't escape '/' because we use it as a path separator.
+#ifdef __MINGW32__
+  static const char WIN_INVALID_PATH_CHARS[] =
+    { '"', '*', ':', '<', '>', '?', '\\', '|' };
+#endif // __MINGW32__
+  std::string d;
+  for(std::string::const_iterator i = s.begin(), eoi = s.end(); i != eoi; ++i) {
+    unsigned char c = *i;
+    if(in(c, 0x00u, 0x1fu) || c == 0x7fu
+#ifdef __MINGW32__
+       || std::find(vbegin(WIN_INVALID_PATH_CHARS),
+                    vend(WIN_INVALID_PATH_CHARS),
+                    c) != vend(WIN_INVALID_PATH_CHARS)
+
+#endif // __MINGW32__
+       ){
+      d += StringFormat("%%%02X", c).str();
+    } else {
+      d += *i;
+    }
+  }
   return d;
 }
 
@@ -1344,6 +1415,81 @@ void removeMetalinkContentTypes(const SharedHandle<RequestGroup>& group)
   }
 }
 
+void executeHook(const std::string& command, const std::string& arg)
+{
+  LogFactory::getInstance()->info("Executing user command: %s %s",
+                                  command.c_str(), arg.c_str());
+#ifndef __MINGW32__
+  pid_t cpid = fork();
+  if(cpid == -1) {
+    LogFactory::getInstance()->error("fork() failed."
+                                     " Cannot execute user command.");
+  } else if(cpid == 0) {
+    execl(command.c_str(), command.c_str(), arg.c_str(),
+          reinterpret_cast<char*>(0));
+    perror(("Could not execute user command: "+command).c_str());
+    exit(EXIT_FAILURE);
+  }
+#else
+  PROCESS_INFORMATION pi;
+  STARTUPINFO si;
+
+  memset(&si, 0, sizeof (si));
+  si.cb = sizeof(STARTUPINFO);
+
+  memset(&pi, 0, sizeof (pi));
+
+  std::string cmdline = command;
+  strappend(cmdline, " ", arg);
+
+  DWORD rc = CreateProcess(
+                           NULL,
+                           (LPSTR)cmdline.c_str(),
+                           NULL,
+                           NULL,
+                           true,
+                           NULL,
+                           NULL,
+                           0,
+                           &si,
+                           &pi);
+
+  if(!rc)
+    LogFactory::getInstance()->error("CreateProcess() failed."
+                                     " Cannot execute user command.");
+#endif 
+}
+
+void executeHookByOptName
+(const SharedHandle<RequestGroup>& group, const Option* option,
+ const std::string& opt)
+{
+  executeHookByOptName(group.get(), option, opt);
+}
+
+void executeHookByOptName
+(const RequestGroup* group, const Option* option, const std::string& opt)
+{
+  if(!option->blank(opt)) {
+    executeHook(option->get(opt), util::itos(group->getGID()));
+  }
+}
+
+std::string createSafePath
+(const std::string& dir, const std::string& filename)
+{
+  return util::applyDir
+    (dir,
+     util::isUtf8(filename)?
+     util::fixTaintedBasename(filename):
+     util::escapePath(util::percentEncode(filename)));
+}
+
+std::string encodeNonUtf8(const std::string& s)
+{
+  return util::isUtf8(s)?s:util::percentEncode(s);
+}
+
 } // namespace util
 
 } // namespace aria2
