@@ -9,7 +9,7 @@
 #include "MockDHTMessageDispatcher.h"
 #include "MockDHTMessage.h"
 #include "DHTPeerAnnounceStorage.h"
-#include "bencode.h"
+#include "bencode2.h"
 
 namespace aria2 {
 
@@ -28,11 +28,13 @@ public:
   void testDoReceivedAction();
 
   class MockDHTMessageFactory2:public MockDHTMessageFactory {
-    virtual SharedHandle<DHTMessage>
+    virtual SharedHandle<DHTResponseMessage>
     createAnnouncePeerReplyMessage(const SharedHandle<DHTNode>& remoteNode,
                                    const std::string& transactionID)
     {
-      return SharedHandle<DHTMessage>(new MockDHTMessage(_localNode, remoteNode, "announce_peer", transactionID));
+      return SharedHandle<DHTResponseMessage>
+        (new MockDHTResponseMessage
+         (localNode_, remoteNode, "announce_peer", transactionID));
     }
   };
 };
@@ -59,19 +61,19 @@ void DHTAnnouncePeerMessageTest::testGetBencodedMessage()
   msg.setVersion("A200");
   std::string msgbody = msg.getBencodedMessage();
 
-  BDE dict = BDE::dict();
-  dict["t"] = transactionID;
-  dict["v"] = BDE("A200");
-  dict["y"] = BDE("q");
-  dict["q"] = BDE("announce_peer");
-  BDE aDict = BDE::dict();
-  aDict["id"] = BDE(localNode->getID(), DHT_ID_LENGTH);
-  aDict["info_hash"] = BDE(infoHash, DHT_ID_LENGTH);
-  aDict["port"] = port;
-  aDict["token"] = token;
-  dict["a"] = aDict;
+  Dict dict;
+  dict.put("t", transactionID);
+  dict.put("v", "A200");
+  dict.put("y", "q");
+  dict.put("q", "announce_peer");
+  SharedHandle<Dict> aDict = Dict::g();
+  aDict->put("id", String::g(localNode->getID(), DHT_ID_LENGTH));
+  aDict->put("info_hash", String::g(infoHash, DHT_ID_LENGTH));
+  aDict->put("port", Integer::g(port));
+  aDict->put("token", token);
+  dict.put("a", aDict);
 
-  CPPUNIT_ASSERT_EQUAL(util::percentEncode(bencode::encode(dict)),
+  CPPUNIT_ASSERT_EQUAL(util::percentEncode(bencode2::encode(&dict)),
                        util::percentEncode(msgbody));
 }
 
@@ -105,9 +107,10 @@ void DHTAnnouncePeerMessageTest::testDoReceivedAction()
 
   msg.doReceivedAction();
 
-  CPPUNIT_ASSERT_EQUAL((size_t)1, dispatcher._messageQueue.size());
-  SharedHandle<MockDHTMessage> m
-    (dynamic_pointer_cast<MockDHTMessage>(dispatcher._messageQueue[0]._message));
+  CPPUNIT_ASSERT_EQUAL((size_t)1, dispatcher.messageQueue_.size());
+  SharedHandle<MockDHTResponseMessage> m
+    (dynamic_pointer_cast<MockDHTResponseMessage>
+     (dispatcher.messageQueue_[0].message_));
   CPPUNIT_ASSERT(localNode == m->getLocalNode());
   CPPUNIT_ASSERT(remoteNode == m->getRemoteNode());
   CPPUNIT_ASSERT_EQUAL(std::string("announce_peer"), m->getMessageType());
@@ -117,8 +120,8 @@ void DHTAnnouncePeerMessageTest::testDoReceivedAction()
   CPPUNIT_ASSERT_EQUAL((size_t)1, peers.size());
   {
     SharedHandle<Peer> peer = peers[0];
-    CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"), peer->ipaddr);
-    CPPUNIT_ASSERT_EQUAL((uint16_t)6882, peer->port);
+    CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"), peer->getIPAddress());
+    CPPUNIT_ASSERT_EQUAL((uint16_t)6882, peer->getPort());
   }
 }
 
