@@ -4,7 +4,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-#include "Util.h"
+#include "util.h"
 #include "Exception.h"
 #include "Peer.h"
 #include "Option.h"
@@ -53,7 +53,7 @@ public:
 CPPUNIT_TEST_SUITE_REGISTRATION(DefaultPeerStorageTest);
 
 void DefaultPeerStorageTest::testCountPeer() {
-  DefaultPeerStorage ps(option);
+  DefaultPeerStorage ps;
 
   CPPUNIT_ASSERT_EQUAL((size_t)0, ps.countPeer());
 
@@ -64,7 +64,7 @@ void DefaultPeerStorageTest::testCountPeer() {
 }
 
 void DefaultPeerStorageTest::testDeleteUnusedPeer() {
-  DefaultPeerStorage ps(option);
+  DefaultPeerStorage ps;
 
   SharedHandle<Peer> peer1(new Peer("192.168.0.1", 6889));
   SharedHandle<Peer> peer2(new Peer("192.168.0.2", 6889));
@@ -78,7 +78,7 @@ void DefaultPeerStorageTest::testDeleteUnusedPeer() {
 
   CPPUNIT_ASSERT_EQUAL((size_t)1, ps.countPeer());
   CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.3"),
-		       ps.getPeer("192.168.0.3", 6889)->ipaddr);
+                       ps.getPeer("192.168.0.3", 6889)->getIPAddress());
 
   ps.addPeer(peer1);
   ps.addPeer(peer2);
@@ -90,12 +90,12 @@ void DefaultPeerStorageTest::testDeleteUnusedPeer() {
   // peer2 has been in use, so it did't deleted.
   CPPUNIT_ASSERT_EQUAL((size_t)1, ps.countPeer());
   CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"),
-		       ps.getPeer("192.168.0.2", 6889)->ipaddr);
+                       ps.getPeer("192.168.0.2", 6889)->getIPAddress());
   
 }
 
 void DefaultPeerStorageTest::testAddPeer() {
-  DefaultPeerStorage ps(option);
+  DefaultPeerStorage ps;
   SharedHandle<BtRuntime> btRuntime(new BtRuntime());
   btRuntime->setMaxPeers(3);
   ps.setBtRuntime(btRuntime);
@@ -125,14 +125,15 @@ void DefaultPeerStorageTest::testAddPeer() {
 
   SharedHandle<Peer> peer5(new Peer("192.168.0.4", 0));
 
-  peer5->port = 6889;
+  peer5->setPort(6889);
 
-  // this returns false because the peer which has same ip and port has already added
+  // this returns false because the peer which has same ip and port
+  // has already added
   CPPUNIT_ASSERT_EQUAL(false, ps.addPeer(peer5));
 }
 
 void DefaultPeerStorageTest::testGetUnusedPeer() {
-  DefaultPeerStorage ps(option);
+  DefaultPeerStorage ps;
   ps.setBtRuntime(btRuntime);
 
   SharedHandle<Peer> peer1(new Peer("192.168.0.1", 6889));
@@ -140,7 +141,7 @@ void DefaultPeerStorageTest::testGetUnusedPeer() {
   ps.addPeer(peer1);
 
   CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"),
-		       ps.getUnusedPeer()->ipaddr);
+                       ps.getUnusedPeer()->getIPAddress());
 
   peer1->usedBy(1);
 
@@ -153,7 +154,7 @@ void DefaultPeerStorageTest::testGetUnusedPeer() {
 }
 
 void DefaultPeerStorageTest::testIsPeerAvailable() {
-  DefaultPeerStorage ps(option);
+  DefaultPeerStorage ps;
   ps.setBtRuntime(btRuntime);
 
   CPPUNIT_ASSERT_EQUAL(false, ps.isPeerAvailable());
@@ -176,10 +177,10 @@ void DefaultPeerStorageTest::testIsPeerAvailable() {
 }
 
 void DefaultPeerStorageTest::testActivatePeer() {
-  DefaultPeerStorage ps(option);
+  DefaultPeerStorage ps;
 
   {
-    std::deque<SharedHandle<Peer> > peers;
+    std::vector<SharedHandle<Peer> > peers;
     ps.getActivePeers(peers);
     CPPUNIT_ASSERT_EQUAL((size_t)0, peers.size());
   }
@@ -189,7 +190,7 @@ void DefaultPeerStorageTest::testActivatePeer() {
   ps.addPeer(peer1);
 
   {
-    std::deque<SharedHandle<Peer> > activePeers;
+    std::vector<SharedHandle<Peer> > activePeers;
     ps.getActivePeers(activePeers);
 
     CPPUNIT_ASSERT_EQUAL((size_t)0, activePeers.size());
@@ -197,7 +198,7 @@ void DefaultPeerStorageTest::testActivatePeer() {
   {
     peer1->allocateSessionResource(1024*1024, 1024*1024*10);
 
-    std::deque<SharedHandle<Peer> > activePeers;
+    std::vector<SharedHandle<Peer> > activePeers;
     ps.getActivePeers(activePeers);
     
     CPPUNIT_ASSERT_EQUAL((size_t)1, activePeers.size());
@@ -209,13 +210,14 @@ void DefaultPeerStorageTest::testCalculateStat() {
 
 void DefaultPeerStorageTest::testReturnPeer()
 {
-  DefaultPeerStorage ps(option);
+  DefaultPeerStorage ps;
 
   SharedHandle<Peer> peer1(new Peer("192.168.0.1", 0));
   peer1->allocateSessionResource(1024*1024, 1024*1024*10);
   SharedHandle<Peer> peer2(new Peer("192.168.0.2", 6889));
   peer2->allocateSessionResource(1024*1024, 1024*1024*10);
   SharedHandle<Peer> peer3(new Peer("192.168.0.1", 6889));
+  peer2->setDisconnectedGracefully(true);
   ps.addPeer(peer1);
   ps.addPeer(peer2);
   ps.addPeer(peer3);
@@ -223,11 +225,13 @@ void DefaultPeerStorageTest::testReturnPeer()
   ps.returnPeer(peer2); // peer2 removed from the container
   CPPUNIT_ASSERT_EQUAL((size_t)2, ps.getPeers().size());
   CPPUNIT_ASSERT(std::find(ps.getPeers().begin(), ps.getPeers().end(), peer2)
-		 == ps.getPeers().end());
+                 == ps.getPeers().end());
+  CPPUNIT_ASSERT_EQUAL((size_t)1, ps.getDroppedPeers().size());
 
   ps.returnPeer(peer1); // peer1 is removed from the container
   CPPUNIT_ASSERT_EQUAL((size_t)1, ps.getPeers().size());
   CPPUNIT_ASSERT(std::find(ps.getPeers().begin(), ps.getPeers().end(), peer1) == ps.getPeers().end());
+  CPPUNIT_ASSERT_EQUAL((size_t)1, ps.getDroppedPeers().size());
 }
 
 void DefaultPeerStorageTest::testOnErasingPeer()
